@@ -6,6 +6,14 @@ from .runner_base import BaseRunner
 from .constants import *
 from .utils import *
 
+LINEAR_ALGORITHMS = [
+    'linear-regression', 
+    'bayesian-ridge-regression', 
+    'lasso-regression', 
+    'ridge-regression', 
+]
+
+
 class RegressionRunner(BaseRunner):
     """
     Run the regression pipeline
@@ -327,7 +335,7 @@ class RegressionRunner(BaseRunner):
                 outcome_var=fref['forward'][outcome_var],
                 categorical_fields=[ fref['forward'][var] for var in categorical_vars ], 
                 saturation_fields=[ fref['forward'][var] for var in saturation_vars ],
-                lagging_fields==[ fref['forward'][var] for var in lagging_vars ],
+                lagging_fields=[ fref['forward'][var] for var in lagging_vars ],
                 algorithm=algorithm,
                 train_size=train_size,
                 verbose=verbose,
@@ -445,7 +453,7 @@ class RegressionRunner(BaseRunner):
         stats['Value'] = stats['Value'].astype('float')
 
         # Coefs
-        if self.__algorithm in ['linear-regression', 'bayesian-ridge-regression', 'lasso-regression', 'ridge-regression']: 
+        if self.__algorithm in LINEAR_ALGORITHMS: 
             if verbose: print('    Retrieving coefficients...')
             coefs = self._buffer_read(
                 request_id=request_id, client_id=client_id, dataframe_name='coefs',
@@ -459,12 +467,7 @@ class RegressionRunner(BaseRunner):
             coefs = None
 
         # Saturation and lagging parameters
-        if self.__algorithm in [
-            'linear-regression', 
-            'bayesian-ridge-regression', 
-            'lasso-regression', 
-            'ridge-regression', 
-        ] and self.__includes_carryover_saturation is True: 
+        if self.__algorithm in LINEAR_ALGORITHMS and self.__includes_carryover_saturation is True: 
             if verbose: print('    Retrieving saturation and lagging parameters...')
             carrysats = self._buffer_read(
                 request_id=request_id, client_id=client_id, dataframe_name='carrysats',
@@ -472,9 +475,24 @@ class RegressionRunner(BaseRunner):
             carrysats['Value'] = carrysats['Value'].astype('float')
             for idx, row in carrysats.iterrows():
                 carrysats.loc[idx, 'Variable'] = fref_decode_value(
-                    coefs.loc[idx, 'Variable'],
+                    carrysats.loc[idx, 'Variable'],
                     fref)
         else:
             carrysats = None
 
-        return features, stats, coefs, carrysats
+        # Elasticities
+        if self.__algorithm in LINEAR_ALGORITHMS: 
+            if verbose: print('    Retrieving elasticities...')
+            elasticities = self._buffer_read(
+                request_id=request_id, client_id=client_id, dataframe_name='elasticities',
+                verbose=verbose)
+            elasticities['Value'] = coefs['Value'].astype('float')
+            for idx, row in elasticities.iterrows():
+                elasticities.loc[idx, 'Parameter'] = fref_decode_value(
+                    elasticities.loc[idx, 'Parameter'],
+                    fref)
+        else:
+            elasticities = None
+
+
+        return features, stats, coefs, carrysats, elasticities
